@@ -46,6 +46,7 @@ import datetime
 
 from pynspect.rules import FilteringRuleException
 
+from html import escape
 
 class BaseRuleTreeTraverser(object):
     """
@@ -370,7 +371,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-ipv4"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-ipv4"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def ipv6(self, rule, **kwargs):
         """
@@ -380,7 +381,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-ipv6"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-ipv6"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def datetime(self, rule, **kwargs):
         """
@@ -390,7 +391,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-datetime"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-datetime"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def timedelta(self, rule, **kwargs):
         """
@@ -400,7 +401,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-timedelta"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-timedelta"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def integer(self, rule, **kwargs):
         """
@@ -410,7 +411,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-integer"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-integer"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def float(self, rule, **kwargs):
         """
@@ -420,7 +421,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-float"><code>{}</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-float"><code>{}</code></div>'.format(escape(str(rule.value)))
 
     def constant(self, rule, **kwargs):
         """
@@ -430,7 +431,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-constant pynspect-rule-constant-string"><code>&quot;{}&quot;</code></div>'.format(rule.value)
+        return '<div class="pynspect-rule-constant pynspect-rule-constant-string"><code>&quot;{}&quot;</code></div>'.format(escape(str(rule.value)))
 
     def variable(self, rule, **kwargs):
         """
@@ -440,7 +441,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param pynspect.rules.Rule rule: Reference to rule.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-variable"><kbd>{}</kbd></div>'.format(rule.value)
+        return '<div class="pynspect-rule-variable"><kbd>{}</kbd></div>'.format(escape(str(rule.value)))
 
     def list(self, rule, **kwargs):
         """
@@ -462,7 +463,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param right: right operand for operation.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-operation pynspect-rule-operation-logical"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(rule.operation, left, right)
+        return '<div class="pynspect-rule-operation pynspect-rule-operation-logical"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(escape(str(rule.operation)), left, right)
 
     def binary_operation_comparison(self, rule, left, right, **kwargs):
         """
@@ -474,7 +475,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param right: right operand for operation.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-operation pynspect-rule-operation-comparison"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(rule.operation, left, right)
+        return '<div class="pynspect-rule-operation pynspect-rule-operation-comparison"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(escape(str(rule.operation)), left, right)
 
     def binary_operation_math(self, rule, left, right, **kwargs):
         """
@@ -486,7 +487,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param right: right operand for operation.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-operation pynspect-rule-operation-math"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(rule.operation, left, right)
+        return '<div class="pynspect-rule-operation pynspect-rule-operation-math"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-left">{}</li><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(escape(str(rule.operation)), left, right)
 
     def unary_operation(self, rule, right, **kwargs):
         """
@@ -497,7 +498,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param right: right operand for operation.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-operation pynspect-rule-operation-unary"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(rule.operation, right)
+        return '<div class="pynspect-rule-operation pynspect-rule-operation-unary"><h3 class="pynspect-rule-operation-name">{}</h3><ul class="pynspect-rule-operation-arguments"><li class="pynspect-rule-operation-argument-right">{}</li></ul></div>'.format(escape(str(rule.operation)), right)
 
     def function(self, rule, args, **kwargs):
         """
@@ -508,7 +509,7 @@ class HTMLTreeTraverser(BaseRuleTreeTraverser):
         :param args: Optional function arguments.
         :param dict kwargs: Optional callback arguments.
         """
-        return '<div class="pynspect-rule-function"><h3 class="pynspect-rule-function-name">{}</h3><ul class="pynspect-rule-function-arguments>{}</ul></div>'.format(rule.function, ''.join(['<li class="pynspect-rule-function-argument">{}</li>'.format(v) for v in args]))
+        return '<div class="pynspect-rule-function"><h3 class="pynspect-rule-function-name">{}</h3><ul class="pynspect-rule-function-arguments>{}</ul></div>'.format(escape(str(rule.function)), ''.join(['<li class="pynspect-rule-function-argument">{}</li>'.format(v) for v in args]))
 
 
 #-------------------------------------------------------------------------------
